==> flink-runtime_2.11-1.6.2-sources.jar: org/apache/flink/runtime/rest/messages/job/metrics/JobsFilterQueryParameter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.messages.job.metrics;

import org.apache.flink.api.common.JobID;
import org.apache.flink.runtime.rest.messages.ConversionException;
import org.apache.flink.runtime.rest.messages.MessageQueryParameter;


/**
 * {@link MessageQueryParameter} for selecting jobs when aggregating metrics.
 */
public class JobsFilterQueryParameter extends MessageQueryParameter<JobID> {

	JobsFilterQueryParameter() {
		super("jobs", MessageParameterRequisiteness.OPTIONAL);
	}

	@Override
	public JobID convertStringToValue(String value) throws ConversionException {
		try {
			return JobID.fromHexString(value);
		} catch (IllegalArgumentException iae) {
			throw new ConversionException("Not a valid job ID: " + value, iae);
		}
	}

	@Override
	public String convertValueToString(JobID value) {
		return value.toString();
	}
}

==> flink-runtime_2.12-1.9.0-sources.jar: org/apache/flink/runtime/rest/messages/job/metrics/JobsFilterQueryParameter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.messages.job.metrics;

import org.apache.flink.api.common.JobID;
import org.apache.flink.runtime.rest.messages.ConversionException;
import org.apache.flink.runtime.rest.messages.MessageQueryParameter;


/**
 * {@link MessageQueryParameter} for selecting jobs when aggregating metrics.
 */
public class JobsFilterQueryParameter extends MessageQueryParameter<JobID> {

	JobsFilterQueryParameter() {
		super("jobs", MessageParameterRequisiteness.OPTIONAL);
	}

	@Override
	public JobID convertStringToValue(String value) throws ConversionException {
		try {
			return JobID.fromHexString(value);
		} catch (IllegalArgumentException iae) {
			throw new ConversionException("Not a valid job ID: " + value, iae);
		}
	}

	@Override
	public String convertValueToString(JobID value) {
		return value.toString();
	}

	@Override
	public String getDescription() {
		return "Comma-separated list of 32-character hexadecimal strings to select specific jobs.";
	}
}
